IF OBJECT_ID('[PipelineStageTargetExecutions_Extended]') IS NOT NULL DROP VIEW [PipelineStageTargetExecutions_Extended]
GO

CREATE VIEW [PipelineStageTargetExecutions_Extended] AS

	SELECT BE.[Execution_Id]
		  ,A.[Application_Id]
		  ,R.[Release_Id]
		  ,R.[Release_Number]
		  ,B.[Build_Id]
		  ,B.[Build_Number]
		  ,B.[BuildStatus_Name]
		  ,[Pipeline_Name] = COALESCE(B.[Pipeline_Name], R.[Pipeline_Name])
		  ,ENV.[Environment_Id]
		  ,ENV.[Environment_Name]
		  ,BP.[Promotion_Id]
		  ,BP.[PipelineStage_Name]
		  ,BE.[Plan_Name]
		  ,[ExecutionStart_Date] = E.[Start_Date]
		  ,[ExecutionEnded_Date] = E.[End_Date]
		  ,E.[ExecutionRunState_Code]
		  ,E.[ExecutionStatus_Code]
		  ,[ExecutionStatus_Name] =
		   CASE
				WHEN E.[ExecutionRunState_Code] = 'P' THEN 'Pending'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NULL THEN 'Executing'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NOT NULL THEN 'Canceled'
				WHEN E.[ExecutionStatus_Code] = 'E' THEN 'Failed'
				ELSE 'Succeeded'
		   END
		  ,E.[CreatedBy_User_Name]
		  ,E.[CreatedOn_Date]
		  ,E.[CanceledBy_User_Name]
		  ,E.[CanceledOn_Date]
		  ,A.[Application_Name]
		  ,BP.[PromotionStatus_Name]
		  ,BP.[Promoted_Date]
		  ,BP.[PromotedBy_Name]
		  ,[WarningLogEntry_Indicator] = CASE WHEN E.[ExecutionStatus_Code] = 'W' THEN 'Y' ELSE 'N' END
          ,[Release_Name] = COALESCE(R.[Release_Name], R.[Release_Number])
		  ,R.[ReleaseStatus_Name]
		  ,A.[ApplicationGroup_Id]
		  ,R.[Release_Sequence]
          ,BE.[PipelineStageTarget_Index]
		  ,BE.[PipelineStageDeploymentExecution_Id]

	  FROM [PipelineStageTargetExecutions] BE
	       INNER JOIN [Executions] E
		          ON E.[Execution_Id] = BE.[Execution_Id]
		   INNER JOIN [BuildPromotions] BP
		           ON BP.[Promotion_Id] = BE.[Promotion_Id]
		   INNER JOIN [Builds] B
				  ON B.[Build_Id] = BP.[Build_Id]
            LEFT JOIN [Releases] R
				  ON R.[Release_Id] = B.[Release_Id]
		    LEFT JOIN [Applications] A
				  ON A.[Application_Id] = B.[Application_Id]
		    LEFT JOIN [Environments] ENV
			       ON ENV.[Environment_Name] = BE.[Environment_Name]

GO
