EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_PurgeConfigurationFile',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges a configuration file, including all previous versions of all instances and deployment history.'
GO

IF OBJECT_ID('[ConfigurationFiles_PurgeConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_PurgeConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_PurgeConfigurationFile]
(
	@ConfigurationFile_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Application_Id INT
	DECLARE @ConfigurationFile_Name NVARCHAR(500)
	SELECT @Application_Id = [Application_Id],
	       @ConfigurationFile_Name = COALESCE([ConfigurationFile_Name], [FilePath_Text])
	  FROM [ConfigurationFiles]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	DELETE [ConfigurationFileDeployments]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	DELETE [ReleaseConfigurationFiles]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	DELETE [ConfigurationFileVersions]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	DELETE [ConfigurationFileInstances]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	DELETE [ConfigurationFiles]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	EXEC [Events_RaiseEvent] 'CFGDEL', @Application_Id, @ConfigurationFile_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_PurgeConfigurationFile] TO [BuildMasterUser_Role]
