﻿IF OBJECT_ID('[RepositoryMonitors_SetState]') IS NOT NULL DROP PROCEDURE [RepositoryMonitors_SetState]
GO

SET QUOTED_IDENTIFIER ON
GO

EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RepositoryMonitors_SetState',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records repository state information.'
GO

CREATE PROCEDURE [RepositoryMonitors_SetState]
(
	@RepositoryMonitor_Id INT,
	@Application_Id INT,
	@Branch_Name VARCHAR(200),
	@RepositoryState_Configuration XML
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @RepositoryState_Configuration IS NULL

		DELETE [RepositoryMonitorStates]
		 WHERE [RepositoryMonitor_Id] = @RepositoryMonitor_Id
		   AND [Application_Id] = @Application_Id
		   AND [Branch_Name] = @Branch_Name

	ELSE IF EXISTS(SELECT * FROM [RepositoryMonitorStates] WITH (UPDLOCK) WHERE [RepositoryMonitor_Id] = @RepositoryMonitor_Id AND [Application_Id] = @Application_Id AND [Branch_Name] = @Branch_Name)

		UPDATE [RepositoryMonitorStates]
		   SET [RepositoryState_Configuration] = @RepositoryState_Configuration,
		       [LastUpdated_Date] = GETUTCDATE()
		 WHERE [RepositoryMonitor_Id] = @RepositoryMonitor_Id
		   AND [Application_Id] = @Application_Id
		   AND [Branch_Name] = @Branch_Name

	ELSE

		INSERT INTO [RepositoryMonitorStates]
		(
			[RepositoryMonitor_Id],
			[Application_Id],
			[Branch_Name],
			[RepositoryState_Configuration],
			[LastUpdated_Date]
		)
		VALUES
		(
			@RepositoryMonitor_Id,
			@Application_Id,
			@Branch_Name,
			@RepositoryState_Configuration,
			GETUTCDATE()
		)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RepositoryMonitors_SetState] TO [BuildMasterUser_Role]
