IF OBJECT_ID('[dbo].[Users_CreateGroup]') IS NOT NULL DROP PROCEDURE [dbo].[Users_CreateGroup]
GO


EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Users_CreateOrUpdateGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new user group in the system'
GO

IF OBJECT_ID('[dbo].[Users_CreateOrUpdateGroup]') IS NOT NULL
	DROP PROCEDURE [dbo].[Users_CreateOrUpdateGroup]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[Users_CreateOrUpdateGroup]
(
	@Group_Name VARCHAR(50),
	@Users_Xml XML
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
				FROM [Users]
			   WHERE [User_Name] = @Group_Name)
		RAISERROR('Cannot create group "%s"; a user of the same name exists', 16, 1)

	IF NOT EXISTS(SELECT * FROM [Groups] WHERE [Group_Name] = @Group_Name)
    BEGIN
        
        INSERT INTO [Groups] ([Group_Name]) VALUES (@Group_Name)
        EXEC [Events_RaiseEvent] 'USRNWG', NULL, @Group_Name

    END

    IF @Users_Xml IS NOT NULL 
    BEGIN

	    DELETE [UserGroups] WHERE [Group_Name] = @Group_Name

	    INSERT INTO [UserGroups] ([User_Name] ,[Group_Name])
	    SELECT UX.[value]('.', 'VARCHAR(250)') [User_Name], @Group_Name
	      FROM @Users_Xml.[nodes]('/users/username') AS UsersXml(UX)

    END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [dbo].[Users_CreateOrUpdateGroup] TO [BuildMasterUser_Role]
GO
